summaryrefslogtreecommitdiff
path: root/nsswitch
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-01-22 13:54:03 +0100
committerMichael Adam <obnox@samba.org>2010-08-14 02:10:32 +0200
commit788123ec2e975bd9019aa9a8a70f4a95b82431b8 (patch)
tree9c037cb8caa069a66e330d16fa7046faac277e3b /nsswitch
parent2e657035081984b84063e1fbb6f6e3314e8d6166 (diff)
downloadsamba-788123ec2e975bd9019aa9a8a70f4a95b82431b8.tar.gz
samba-788123ec2e975bd9019aa9a8a70f4a95b82431b8.tar.bz2
samba-788123ec2e975bd9019aa9a8a70f4a95b82431b8.zip
libwbclient: unimplement wbcSetGidMapping()
Michael
Diffstat (limited to 'nsswitch')
-rw-r--r--nsswitch/libwbclient/wbc_idmap.c35
1 files changed, 2 insertions, 33 deletions
diff --git a/nsswitch/libwbclient/wbc_idmap.c b/nsswitch/libwbclient/wbc_idmap.c
index 4f5140e1bb..1c31a91281 100644
--- a/nsswitch/libwbclient/wbc_idmap.c
+++ b/nsswitch/libwbclient/wbc_idmap.c
@@ -277,41 +277,10 @@ wbcErr wbcSetUidMapping(uid_t uid, const struct wbcDomainSid *sid)
return WBC_ERR_NOT_IMPLEMENTED;
}
/* Set a group id mapping */
wbcErr wbcSetGidMapping(gid_t gid, const struct wbcDomainSid *sid)
{
- struct winbindd_request request;
- struct winbindd_response response;
- wbcErr wbc_status = WBC_ERR_UNKNOWN_FAILURE;
- char *sid_string = NULL;
-
- if (!sid) {
- return WBC_ERR_INVALID_PARAM;
- }
-
- /* Initialise request */
-
- ZERO_STRUCT(request);
- ZERO_STRUCT(response);
-
- /* Make request */
-
- request.data.dual_idmapset.id = gid;
- request.data.dual_idmapset.type = _ID_TYPE_GID;
-
- wbc_status = wbcSidToString(sid, &sid_string);
- BAIL_ON_WBC_ERROR(wbc_status);
-
- strncpy(request.data.dual_idmapset.sid, sid_string,
- sizeof(request.data.dual_idmapset.sid)-1);
- wbcFreeMemory(sid_string);
-
- wbc_status = wbcRequestResponsePriv(WINBINDD_SET_MAPPING,
- &request, &response);
- BAIL_ON_WBC_ERROR(wbc_status);
-
- done:
- return wbc_status;
+ return WBC_ERR_NOT_IMPLEMENTED;
}
/* Remove a user id mapping */
@@ -277,41 +277,10 @@ wbcErr wbcSetUidMapping(uid_t uid, const struct wbcDomainSid *sid)
return WBC_ERR_NOT_IMPLEMENTED;
}
-/* Set a group id mapping */
+/* Set a group id mapping - not implemented any more */
wbcErr wbcSetGidMapping(gid_t gid, const struct wbcDomainSid *sid)
{